package main

import (
	"errors"
	"fmt"
	"io/ioutil"
	"net"
	"os"
	"path"
	"text/template"
)

const pxeUserTplPath = "pxelinux.cfg/tpl"
const pxeUserPath = "pxelinux.cfg"

func RegisterUserMAC(ip net.IP, username string) error {
	if tab, err := ARPAnalyze(); err != nil {
		return err
	} else if ent := ARPContainsIP(tab, ip); ent == nil {
		return errors.New(fmt.Sprintf("Unable to find MAC address for given IP (%s)", ip))
	} else {
		return registerUser(fmt.Sprintf("%02X-%02X-%02X-%02X-%02X-%02X-%02X", ent.HWType, ent.HWAddress[0], ent.HWAddress[1], ent.HWAddress[2], ent.HWAddress[3], ent.HWAddress[4], ent.HWAddress[5]), username)
	}
}

func RegisterUserIP(ip net.IP, username string) error {
	return registerUser(fmt.Sprintf("%02X%02X%02X%02X", ip.To4()[0], ip.To4()[1], ip.To4()[2], ip.To4()[3]), username)
}

func registerUser(filename string, username string) error {
	if pxeTplCnt, err := ioutil.ReadFile(path.Join(tftpDir, pxeUserTplPath)); err != nil {
		return err
	} else if userfd, err := os.OpenFile(path.Join(tftpDir, pxeUserPath, filename), os.O_RDWR|os.O_CREATE, 0644); err != nil {
		return err
	} else {
		defer userfd.Close()
		if pxeTmpl, err := template.New("pxeUser").Parse(string(pxeTplCnt)); err != nil {
			return err
		} else if err := pxeTmpl.Execute(userfd, map[string]string{"username": username}); err != nil {
			return err
		}
	}
	return nil
}
